@@ -1,21 +1,24 @@
 """Base for interacting with the Censys Assets API."""
+import re
 from typing import Iterator, Optional
 
 from ..api import CensysAsmAPI
 from censys.common.exceptions import CensysInvalidColorException
 
+HEX_REGEX = re.compile(r"^#(?:[0-9a-fA-F]{3}){1,2}$")
+
 
 class Assets(CensysAsmAPI):
-    """Assets API class.
-
-    Args:
-        asset_type (str): Type of asset to interact with.
-        *args: Variable length argument list.
-        **kwargs: Arbitrary keyword arguments.
-    """
+    """Assets API class."""
 
     def __init__(self, asset_type: str, *args, **kwargs):
-        """Inits Assets."""
+        """Inits Assets.
+
+        Args:
+            asset_type (str): Type of asset to interact with.
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+        """
         CensysAsmAPI.__init__(self, *args, **kwargs)
         self.base_path = f"assets/{asset_type}"
 
@@ -66,7 +69,9 @@ class Assets(CensysAsmAPI):
         """
         path = f"{self.base_path}/{asset_id}/comments"
 
-        return self._get_page(path, page_number=page_number, page_size=page_size)
+        return self._get_page(
+            path, page_number=page_number, page_size=page_size, keyword="comments"
+        )
 
     def get_comment_by_id(self, asset_id: str, comment_id: int) -> dict:
         """Requests a comment on a specified asset by comment ID.
@@ -97,6 +102,20 @@ class Assets(CensysAsmAPI):
 
         return self._post(path, data=data)
 
+    def delete_comment(self, asset_id: str, comment_id: int) -> dict:
+        """Deletes a comment from a specified asset on the ASM platform by comment ID.
+
+        Args:
+            asset_id (str): Asset ID to delete comment from.
+            comment_id (int): Comment ID to delete.
+
+        Returns:
+            dict: Deleted comment results.
+        """
+        path = f"{self.base_path}/{asset_id}/comments/{comment_id}"
+
+        return self._delete(path)
+
     def add_tag(self, asset_id: str, name: str, color: Optional[str] = None) -> dict:
         """Adds a tag to a specified asset on the ASM platform.
 
@@ -135,11 +154,14 @@ def format_tag(name: str, color: Optional[str] = None) -> dict:
         name (str): Tag name.
         color (str): Optional; Tag color (hex).
 
+    Raises:
+        CensysInvalidColorException: Raised if color is not a valid hex color.
+
     Returns:
         dict: Formatted tag request data.
     """
     if color:
-        if not color.startswith("#"):
+        if not HEX_REGEX.match(color):
             raise CensysInvalidColorException(10037, f"{color} is not a valid color.")
         return {"name": str(name), "color": str(color)}
 
